==> haskell-terminal-progress-bar-0.4.2-121-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-terminal-progress-bar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 terminal-progress-bar
version:              0.4.2
visibility:           public
id:                   terminal-progress-bar-0.4.2-FkwhEaBBbmRE9tdVAb2Wvt
key:                  terminal-progress-bar-0.4.2-FkwhEaBBbmRE9tdVAb2Wvt
license:              BSD-3-Clause
copyright:            2012–2019 Roel van Dijk <roel@lambdacube.nl>
maintainer:           Roel van Dijk <roel@lambdacube.nl>
author:               Roel van Dijk <roel@lambdacube.nl>
homepage:             https://github.com/roelvandijk/terminal-progress-bar
synopsis:             A progress bar in the terminal
description:
    A progress bar conveys the progress of a task. This package
    implements a progress bar that is displayed in a terminal.

    See the module '\''System.ProgressBar'\'' to get started or look at the
    terminal-progress-bar-example package.

    The animated progress bar depends entirely on the interpretation of
    the carriage return character (\'\''\\r\'\''). If your terminal interprets
    it as something else than \"move cursor to beginning of line\", the
    animation won'\''t work.

category:             System, User Interfaces
abi:                  14da29cc430d5ed634270593a4d16447
exposed:              True
exposed-modules:      System.ProgressBar
import-dirs:          /usr/lib/ghc-9.6.6/site-local/terminal-progress-bar-0.4.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/terminal-progress-bar-0.4.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/terminal-progress-bar-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-terminal-progress-bar
hs-libraries:         HSterminal-progress-bar-0.4.2-FkwhEaBBbmRE9tdVAb2Wvt
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    terminal-size-0.3.4-RfZxi4foNwK9w669pzI7h text-2.0.2 time-1.12.2

haddock-interfaces:
    /usr/share/doc/haskell-terminal-progress-bar/html/terminal-progress-bar.haddock

haddock-html:         /usr/share/doc/haskell-terminal-progress-bar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-terminal-progress-bar-0.4.2-122-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-terminal-progress-bar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 terminal-progress-bar
version:              0.4.2
visibility:           public
id:                   terminal-progress-bar-0.4.2-7VMSrzvH1e0GhBamfD7eyr
key:                  terminal-progress-bar-0.4.2-7VMSrzvH1e0GhBamfD7eyr
license:              BSD-3-Clause
copyright:            2012–2019 Roel van Dijk <roel@lambdacube.nl>
maintainer:           Roel van Dijk <roel@lambdacube.nl>
author:               Roel van Dijk <roel@lambdacube.nl>
homepage:             https://github.com/roelvandijk/terminal-progress-bar
synopsis:             A progress bar in the terminal
description:
    A progress bar conveys the progress of a task. This package
    implements a progress bar that is displayed in a terminal.

    See the module '\''System.ProgressBar'\'' to get started or look at the
    terminal-progress-bar-example package.

    The animated progress bar depends entirely on the interpretation of
    the carriage return character (\'\''\\r\'\''). If your terminal interprets
    it as something else than \"move cursor to beginning of line\", the
    animation won'\''t work.

category:             System, User Interfaces
abi:                  53c0d4cd241f9a35b6e034386b08b37b
exposed:              True
exposed-modules:      System.ProgressBar
import-dirs:          /usr/lib/ghc-9.6.6/site-local/terminal-progress-bar-0.4.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/terminal-progress-bar-0.4.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/terminal-progress-bar-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-terminal-progress-bar
hs-libraries:         HSterminal-progress-bar-0.4.2-7VMSrzvH1e0GhBamfD7eyr
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    terminal-size-0.3.4-RfZxi4foNwK9w669pzI7h text-2.0.2 time-1.12.2

haddock-interfaces:
    /usr/share/doc/haskell-terminal-progress-bar/html/terminal-progress-bar.haddock

haddock-html:         /usr/share/doc/haskell-terminal-progress-bar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
